Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(539)

Unified Diff: third_party/WebKit/Source/core/layout/compositing/CompositingInputsUpdater.cpp

Issue 2773163002: Include control clip in list of clip-related properties. (Closed)
Patch Set: Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/Source/core/layout/LayoutObject.cpp ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/Source/core/layout/compositing/CompositingInputsUpdater.cpp
diff --git a/third_party/WebKit/Source/core/layout/compositing/CompositingInputsUpdater.cpp b/third_party/WebKit/Source/core/layout/compositing/CompositingInputsUpdater.cpp
index dbfd4cf3e2ead3dea2ba5451feee795c53260215..9cad0395ff762aa84849abf501c492cec499ec40 100644
--- a/third_party/WebKit/Source/core/layout/compositing/CompositingInputsUpdater.cpp
+++ b/third_party/WebKit/Source/core/layout/compositing/CompositingInputsUpdater.cpp
@@ -48,10 +48,12 @@ static const PaintLayer* findParentLayerOnClippingContainerChain(
if (current->hasLayer())
return static_cast<const LayoutBoxModelObject*>(current)->layer();
// Having clip or overflow clip forces the LayoutObject to become a layer,
// except for contains: paint, which may apply to SVG.
// SVG (other than LayoutSVGRoot) cannot have PaintLayers.
DCHECK(!current->hasClipRelatedProperty() ||
- current->styleRef().containsPaint());
+ current->styleRef().containsPaint() ||
+ (current->isBox() && toLayoutBox(current)->hasControlClip()));
}
ASSERT_NOT_REACHED();
return nullptr;
@@ -48,10 +48,12 @@ static const PaintLayer* findParentLayerOnClippingContainerChain(
return static_cast<const LayoutBoxModelObject*>(current)->layer();
// Having clip or overflow clip forces the LayoutObject to become a layer,
- // except for contains: paint, which may apply to SVG.
+ // except for contains: paint, which may apply to SVG, and
+ // control clip, which may apply to LayoutBox subtypes.
// SVG (other than LayoutSVGRoot) cannot have PaintLayers.
DCHECK(!current->hasClipRelatedProperty() ||
« no previous file with comments | « third_party/WebKit/Source/core/layout/LayoutObject.cpp ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698